#!/usr/bin/perl
#------------------------------------------------------------
#Usage: $prgName output (from glove)
#------------------------------------------------------------
use Math::Trig;
my $PI = pi();

#INPUT PARAMS
#########################################################################3
$gamma = 4258*$PI*2;  	#1H gamma (Hz/Gauss) to rads/G ;
$big_delta = 0.030;  	#diff time (s)
$lil_delta = 0.002; 	#sum of 2 grad pulses (s)
$tau = 200e-6;      	#delay btw 2 grad pulses; 200us about

   $A = ($gamma*$lil_delta)**2;
   $B = $big_delta - 0.33*$lil_delta - 0.5*$tau ;
#   $I = exp(-$D*$A*$B); 	#observed intensity

$Q = $A*$B ;		#scaling factor to get diffusion 
#########################################################################3
#Nothing below here:
#

$filea = $ARGV[0];
$count=0;
open(INA, $filea) || die "Can't open file $filea.\n";
while($line = <INA>){
   @field = split(/\s+/,$line);

if ($line=~ /SET\s+/) {
$vector = $field[1];
($residue_num,$atom_name) = split(/-/,$vector);
}

if ($line=~ /B\s+/) {
$data{$residue_num}{$atom_name}{B} = $field[2];
$data{$residue_num}{$atom_name}{B_error} = $field[3];
}

if ($line=~ /D\s+/) {
$data{$residue_num}{$atom_name}{D} = $field[2];
$data{$residue_num}{$atom_name}{D_error} = $field[3];
}

if ($line=~ /X2\/DoF\s+/) {
if ($line =~ /Global\s+/) {next}
$data{$residue_num}{$atom_name}{chi2} = $field[2];
}
}
close(INA);

# get peak lists from 1D .xpk
open LIST2, $ARGV[1];
while (defined($line = <LIST2>)) {;
        @fields = split(/\s+/, $line);
                        $peak[$i] = $fields[0];
                        ($a[$i], $b[$i]) = split(/:/, $fields[1]);
                        $mean{$peak[$i]}=abs($a[$i] + $b[$i])/2; 
                        $spread{$peak[$i]}=abs($a[$i] - $b[$i])/2;
                        $high[$i] = sprintf("%.3f", $high[$i]);
                        $low[$i] = sprintf("%.3f", $low[$i]);
                        #print "i is $i, peak $peak[$i], ppm is $high[$i] $low[$i]\n";
                #       printf "%3.2f %3.2f\n",  $mean{$peak[$i]}, $spread{$peak[$i]};
                        $i += 1;
                        $numpks=$i;
                        };
                        close LIST2;

#print "#ppm	+/-ppm	D(m2/s e-9) error Chi2/dof \n", $ppm;
print "#ppm(+/-ppm)	D(m2/s e-10)(error)  Chi2/dof \n", $ppm;
foreach $residue_num ( sort numerically keys %data ) {
        foreach $atom_name ( sort keys %{ $data{$residue_num} } ) {
		$val1 = $data{$residue_num}{$atom_name}{B};
		$val1_err = $data{$residue_num}{$atom_name}{B_error};
		$chisq = $data{$residue_num}{$atom_name}{chi2};
		$val2 = $data{$residue_num}{$atom_name}{D};
		$val2_err = $data{$residue_num}{$atom_name}{D_error};
		$ppm=$mean{$residue_num};
		$dppm=$spread{$residue_num};
                #printf "%d\t",$residue_num ;
                #printf "%d\t",$atom_name ;
		$val1_err = substr($val1_err,1); # remove first character of string
		$val1_err = substr($val1_err,0,-1); #remove last char of string 
		$val2_err = substr($val2_err,1); # remove first character of string
		$val2_err = substr($val2_err,0,-1); #remove last char of string 
if ($ppm != 0 && abs($val1)!=0) {
#                printf "%3.2f\t", $ppm;
#                printf "%3.2f\t", abs($val)/$Q;
#                printf "%3.2f\t", $dppm;
#                printf "%3.2f\t", abs($val_err)/$Q;
#                printf "%3.2f\n", $chisq;

                printf " %3.2f", $ppm;
                printf " (%3.2f)\t", $dppm;
                printf "%3.2f", 1e2 * abs($val1)/$Q;
                printf " (%3.2f)\t",1e2 * abs($val1_err)/$Q;
                printf "%3.2f", 1e2 * abs($val2)/$Q;
                printf " (%3.2f)\t",1e2 * abs($val2_err)/$Q;
                printf "%3.3f\n", $chisq;
		}
	}
}
 printf "\n";
 printf "#Input params for DOSY:\n", $gamma;
 printf "#Gamma(Rads/G): %3.0f \n", $gamma;
 printf "#Big_Delta(s): %3.5f \n", $big_delta;
 printf "#Lil_Delta(s): %3.5f \n", $lil_delta;
 printf "#Tau(s): %3.5f \n", $tau;

exit;
sub numerically { $a <=> $b; }
