#!/usr/bin/perl

use Math::Trig;
my $PI = pi();

#input parameters
############################################################

$D = 3.0e-10 ;		#Diffusion rate m2/s * e-9; eg) value*e-9

$big_delta = 0.060 ; 	#diff time (s)
$lil_delta = 0.002 ;	#sum of 2 grad pulses (s)
$tau = 200e-6;		#delay btw 2 grad pulses; 200us about

$gamma = 4257*2*$PI;	#1H gamma (Hz/Gauss) to Rads/Gauss;
#$gamma = 1654;		#7Li gamma (Hz/Gauss);
#
# bruker probe is 5.35G/cmA = 535G/mA
#

$G_probe = 535 ;	#G/m*A
$I_max = 10 ;		#max current A
#
$scale = 0.90       ;	#Smoothed square 10
#$scale = 0.63 ;	#Sine lobe integral
#$scale = 1.00;		#square lobe integral
$G_max = $G_probe*$I_max*$scale;		#max gradient G/m;

$p_low = 5 ;		#G pulse low percent
$p_high = 95 ;		#G pulse high percent
$steps = 16 ;		#number of gradient steps

############################################################

$g_step = ($p_high - $p_low)/($steps-1);	#calc gradient inc

for($i = 1; $i <= $steps; $i = $i + 1){

   $gp =  ($p_low + ($i-1)*$g_step)/100;	#current applied gradient
   $g = $gp*$G_max;

   $A = ($g*$gamma*$lil_delta)**2;
   $B = $big_delta - 0.33*$lil_delta - 0.5*$tau ;
   $I = exp(-$D*$A*$B);				#observed intensity
   #
   #printf"  %3.1f   %4.5f \n",$i,$g;		#applied Gauss/m pulse
   printf"  %3.4f   %4.5f \n",$g / 1e4  ,$I;	# G/cm vs Int
   #printf"%4.5f ",$g;		#applied Gauss/m pulse
}
   printf"&\n";		#intensity vs lil_delta 

#printf"\n";


############################################################
############################################################
############################################################
